@@ -1,10 +1,10 @@
-use structopt::StructOpt;
 use std::path::PathBuf;
 use std::process;
+use structopt::StructOpt;
 
 #[derive(StructOpt, Debug)]
 /// The UNix ARchiver, a simple archive utility compatible with MSVC/GNU/LLVM
-struct CLI {
+struct UnarCli {
     /// Format of generated archive
     #[structopt(short = "f", long = "format", default_value = "gnu")]
     format: String,
@@ -19,7 +19,7 @@ struct CLI {
 }
 
 fn main() {
-    let opt = CLI::from_args();
+    let opt = UnarCli::from_args();
 
     // Check to make sure that the format is one of the following
     // bsd (used by *BSD and darwin), gnu (used by linux and windows) and common (used in .deb packages)
@@ -30,7 +30,7 @@ fn main() {
         _ => {
             eprintln!("error: Invalid Format \"{}\"", opt.format);
             process::exit(1);
-        },
+        }
     }
 
     println!("{:#?}", opt);
